@@ -1,6 +1,6 @@
+#[cfg(feature = "controller")]
 pub mod controller;
 pub mod service;
-pub mod transform;
 pub mod types;
 
 pub const EAPI_VERSION: u16 = 1;
